src/eric7/Debugger/DebugServer.py

branch
eric7-maintenance
changeset 10004
983477114d3c
parent 9654
7328efba128b
parent 9971
773ad1f1ed22
child 10079
0222a480e93d
--- a/src/eric7/Debugger/DebugServer.py	Thu Apr 06 09:32:12 2023 +0200
+++ b/src/eric7/Debugger/DebugServer.py	Tue May 02 10:20:02 2023 +0200
@@ -938,9 +938,9 @@
 
         self.debuggerInterface.newConnection(sock)
 
-    def masterClientConnected(self):
+    def mainClientConnected(self):
         """
         Public method to perform actions after the master client has finally
         established the connection.
         """
         # Perform actions necessary, if client type has changed
@@ -938,9 +938,9 @@
         """
-        Public method to perform actions after the master client has finally
+        Public method to perform actions after the main client has finally
         established the connection.
         """

eric ide

mercurial